@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2000-2013 Greg Sabino Mullane and others: see the Changes file
+    Copyright (c) 2000-2011 Greg Sabino Mullane and others: see the Changes file
 	Portions Copyright (c) 1997-2000 Edmund Mergl
 	Portions Copyright (c) 1994-1997 Tim Bunce
 	
@@ -30,17 +30,14 @@ struct imp_dbh_st {
 	PGconn  *conn;             /* connection structure */
 	char    *sqlstate;         /* from the last result */
 
-
 	bool    pg_bool_tf;        /* do bools return 't'/'f'? Set by user, default is 0 */
+    bool    utf8_strings;      /* so we set the utf8 flag on data from the database? */
+	bool    pg_enable_utf8;    /* (DEPRECATED) should we attempt to make utf8 strings? Set by user, default is 0 */
 	bool    prepare_now;       /* force immediate prepares, even with placeholders. Set by user, default is 0 */
 	bool    done_begin;        /* have we done a begin? (e.g. are we in a transaction?) */
 	bool    dollaronly;        /* only consider $1, $2 ... as valid placeholders */
 	bool    expand_array;      /* transform arrays from the db into Perl arrays? Default is 1 */
 	bool    txn_read_only;     /* are we in read-only mode? Set with $dbh->{ReadOnly} */
-
-	int     pg_enable_utf8;    /* legacy utf8 flag: force utf8 flag on or off, regardless of client_encoding */
-	bool    pg_utf8_flag;      /* are we currently flipping the utf8 flag on? */
-    bool    client_encoding_utf8; /* is the client_encoding utf8 last we checked? */
 };
 
 
@@ -192,7 +189,7 @@ int pg_db_getfd (imp_dbh_t * imp_dbh);
 
 SV * pg_db_pg_notifies (SV *dbh, imp_dbh_t *imp_dbh);
 
-SV * pg_stringify_array(SV * input, const char * array_delim, int server_version);
+SV * pg_stringify_array(SV * input, const char * array_delim, int server_version, int extraquotes);
 
 int pg_quickexec (SV *dbh, const char *sql, const int asyncflag);
 
@@ -232,8 +229,6 @@ int pg_db_lo_lseek (SV *dbh, int fd, int offset, int whence);
 
 int pg_db_lo_tell (SV *dbh, int fd);
 
-int pg_db_lo_truncate (SV *dbh, int fd, size_t len);
-
 int pg_db_lo_unlink (SV *dbh, unsigned int lobjId);
 
 unsigned int pg_db_lo_import (SV *dbh, char *filename);
