@@ -8,7 +8,6 @@ BEGIN {
 use strict;
 use warnings;
 use DBI ':sql_types';
-use utf8;
 use Data::Dumper;
 use YAML;
 use DBD::Pg qw/:pg_types/;
@@ -19,63 +18,17 @@ use vars qw/$sth $info $count $SQL/;
 my $tracelevel = shift || 0;
 $ENV{DBI_TRACE} = $tracelevel;
 
-my $DSN = 'DBI:Pg:dbname=postgres';
+my $dbname = 'latin';
+my $DSN = "DBI:Pg:dbname=$dbname";
+
 my $dbh = DBI->connect($DSN, '', '', {AutoCommit=>0,RaiseError=>1,PrintError=>0})
   or die "Connection failed!\n";
 
 my $me = $dbh->{Driver}{Name};
 print "DBI is version $DBI::VERSION, I am $me, version of DBD::Pg is $DBD::Pg::VERSION\n";
 
-utf8_print_test();
-
-#memory_leak_test_bug_65734();
-
 exit;
 
-
-sub utf8_print_test {
-
-	## Set things up
-	$dbh->do('CREATE TEMPORARY TABLE ctest (c TEXT)');
-
-	## Add some UTF-8 content
-	$dbh->do("INSERT INTO ctest VALUES ('*JIHOMORAVSKÝ*')");
-	$dbh->do("INSERT INTO ctest VALUES ('*Špindlerův Mlýn*')");
-
-	## Pull data back out via execute/bind/fetch
-	$SQL = 'SELECT c FROM ctest';
-
-	my $result;
-
-	for my $loop (1..4) {
-
-		my $onoff = 'off';
-		if ($loop == 1 or $loop==3) {
-			$dbh->{pg_enable_utf8} = 0;
-		}
-		else {
-			$dbh->{pg_enable_utf8} = 1;
-			$onoff = 'on';
-		}
-
-		if ($loop>2) {
-			binmode STDOUT, ':utf8';
-		}
-
-		$sth = $dbh->prepare($SQL);
-		$sth->execute();
-		$sth->bind_columns(\$result);
-		while ($sth->fetch() ) {
-			print DPeek $result;
-			print "\n Print with pg_enable_utf8 $onoff: $result\n";
-			warn " Warn with pg_enable_utf8 $onoff: $result\n\n";
-			utf8::upgrade($result);
-			print DPeek $result; print "\n\n";
-		}
-	}
-
-} ## end of utf8_print_test
-
 sub memory_leak_test_bug_65734 {
 
 	## Memory leak when an array appears in the bind variables
